aboutsummaryrefslogtreecommitdiffstats
path: root/engine/overworld/doors.asm
diff options
context:
space:
mode:
authorYamaArashi <shadow962@live.com>2014-09-13 00:50:56 -0700
committerYamaArashi <shadow962@live.com>2014-09-13 00:50:56 -0700
commit0c916aea3353ed1bf2750be403b0da9ea0b922d4 (patch)
tree4e50d805a37f06fabac6086a7ad6ed1d4f4526c4 /engine/overworld/doors.asm
parentLabelled and commented mostly sprite-related things (diff)
downloadpokeyellow-0c916aea3353ed1bf2750be403b0da9ea0b922d4.tar.gz
pokeyellow-0c916aea3353ed1bf2750be403b0da9ea0b922d4.tar.xz
pokeyellow-0c916aea3353ed1bf2750be403b0da9ea0b922d4.zip
Commented more sprite and map code
Diffstat (limited to 'engine/overworld/doors.asm')
-rwxr-xr-xengine/overworld/doors.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/engine/overworld/doors.asm b/engine/overworld/doors.asm
index 85ff58b2..ac345af9 100755
--- a/engine/overworld/doors.asm
+++ b/engine/overworld/doors.asm
@@ -1,5 +1,5 @@
-; returns whether the player is standing on a door in carry
-IsPlayerStandingOnDoor: ; 1a609 (6:6609)
+; returns whether the player is standing on a door tile in carry
+IsPlayerStandingOnDoorTile: ; 1a609 (6:6609)
push de
ld hl, DoorTileIDPointers ; $662c
ld a, [W_CURMAPTILESET] ; W_CURMAPTILESET